@@ -9,12 +9,12 @@ class ASORA:
 
 async def info(text: str) -> str:
     style = ASORA.info_background + ASORA.white_text
-    print("%s   %s", [colored.stylize("[?]", style), text])
+    print(colored.stylize("[?]", style), text)
 
 async def error(err: str) -> str:
     style = ASORA.err_background + ASORA.white_text
-    print("%s   %s", [colored.stylize("[X]", style), err])
+    print(colored.stylize("[X]", style), err)
 
 async def warning(war: str) -> str:
     style = ASORA.warning_background + ASORA.white_text
-    print("%s   %s", [colored.stylize("[!]", style), war])
+    print(colored.stylize("[!]", style), war)
